==> openGion7.2.4.0_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GEA11S.sql <==
/****************************************************************************/
/* GEA11 ( 画面定義 )                                                       */
/*                                                                          */
/* Created : 2018/09/28 16:03:23                                            */
/****************************************************************************/

CREATE TABLE GEA11 (
   SYSTEM_ID        VARCHAR  (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID   */
 , SEQNO            INTEGER                 DEFAULT 0   NOT NULL            /*  20 表示順   */
 , GUIKEY           VARCHAR  (   30 )                   NOT NULL            /*  30 画面ID   */
 , GUILVL           VARCHAR  (    1 )       DEFAULT '3' NOT NULL            /*  40 画面Lv   */
 , LABEL_CLM        VARCHAR  (   30 )                                       /*  45 ﾗﾍﾞﾙｶﾗﾑ  */
 , GROUPS           VARCHAR  (  500 )                                       /*  50 ｸﾞﾙｰﾌﾟｽ  */
 , NAME_JA          VARCHAR  (  200 )                                       /*  60 名称     */
 , ADDRESS          VARCHAR  (  256 )                                       /*  70 ｱﾄﾞﾚｽ    */
 , ROLES            VARCHAR  ( 2000 )                                       /*  80 ﾛｰﾙｽﾞ    */
 , RWMODE           VARCHAR  (    3 )                                       /*  90 ﾓｰﾄﾞ     */
 , TARGET           VARCHAR  (   10 )                                       /* 100 ﾀｰｹﾞｯﾄ   */
 , PARAM            VARCHAR  (  500 )                                       /* 110 設定値   */
 , KBLINK           VARCHAR  (   10 )                                       /* 120 ﾘﾝｸ区分  */
 , COMMENTS         VARCHAR  (  500 )                                       /* 130 ｺﾒﾝﾄ     */
 , CDKH             VARCHAR  (    1 )                                       /* 140 改廃ｺｰﾄﾞ */
 , KBSAKU           VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 150 作成区分 */
 , RELEASE_NOTES    VARCHAR  (  120 )                                       /* 160 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         VARCHAR  (   20 )                                       /* 170 設変番号 */
 , UNIQ             IDENTITY                                                /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ              VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            VARCHAR  (   14 )                                       /* 820 登録日時 */
 , PGSET            VARCHAR  (   10 )                                       /* 830 作成PG   */
 , PGPSET           VARCHAR  (   10 )                                       /* 840 作成親PG */
 , USRSET           VARCHAR  (   10 )                                       /* 850 作成者   */
 , DYUPD            VARCHAR  (   14 )                                       /* 860 更新日時 */
 , PGUPD            VARCHAR  (   10 )                                       /* 870 更新PG   */
 , PGPUPD           VARCHAR  (   10 )                                       /* 880 更新親PG */
 , USRUPD           VARCHAR  (   10 )                                       /* 890 更新者   */
);

==> openGion7.3.0.1_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GEA11S.sql <==
/****************************************************************************/
/* GEA11 ( 画面定義 )                                                       */
/*                                                                          */
/* Created : 2020/12/16 08:13:57                                            */
/****************************************************************************/

CREATE TABLE GEA11 (
   SYSTEM_ID        VARCHAR  (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID   */
 , SEQNO            INTEGER                 DEFAULT 0   NOT NULL            /*  20 表示順   */
 , GUIKEY           VARCHAR  (   30 )                   NOT NULL            /*  30 画面ID   */
 , GUILVL           VARCHAR  (    1 )       DEFAULT '3' NOT NULL            /*  40 画面Lv   */
 , LABEL_CLM        VARCHAR  (   30 )                                       /*  45 ﾗﾍﾞﾙｶﾗﾑ  */
 , GROUPS           VARCHAR  (  500 )                                       /*  50 ｸﾞﾙｰﾌﾟｽ  */
 , NAME_JA          VARCHAR  (  200 )                                       /*  60 名称     */
 , ADDRESS          VARCHAR  (  256 )                                       /*  70 ｱﾄﾞﾚｽ    */
 , ROLES            VARCHAR  ( 2000 )                                       /*  80 ﾛｰﾙｽﾞ    */
 , RWMODE           VARCHAR  (    3 )                                       /*  90 ﾓｰﾄﾞ     */
 , TARGET           VARCHAR  (   10 )                                       /* 100 ﾀｰｹﾞｯﾄ   */
 , PARAM            VARCHAR  (  500 )                                       /* 110 設定値   */
 , KBLINK           VARCHAR  (   10 )                                       /* 120 ﾘﾝｸ区分  */
 , COMMENTS         VARCHAR  (  500 )                                       /* 130 ｺﾒﾝﾄ     */
 , CDKH             VARCHAR  (    1 )                                       /* 140 改廃ｺｰﾄﾞ */
 , KBSAKU           VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 150 作成区分 */
 , RELEASE_NOTES    VARCHAR  (  120 )                                       /* 160 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         VARCHAR  (   20 )                                       /* 170 設変番号 */
 , UNIQ             IDENTITY                                                /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ              VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            VARCHAR  (   14 )                                       /* 820 作成日時 */
 , PGSET            VARCHAR  (   10 )                                       /* 830 作成PG   */
 , PGPSET           VARCHAR  (   10 )                                       /* 840 作成親PG */
 , USRSET           VARCHAR  (   10 )                                       /* 850 作成者   */
 , DYUPD            VARCHAR  (   14 )                                       /* 860 更新日時 */
 , PGUPD            VARCHAR  (   10 )                                       /* 870 更新PG   */
 , PGPUPD           VARCHAR  (   10 )                                       /* 880 更新親PG */
 , USRUPD           VARCHAR  (   10 )                                       /* 890 更新者   */
);
